@@ -5,8 +5,10 @@ use strict;
 use Carp;
 use SVG;
 
+use overload  '""' => \&to_string;
+
 use 5.008000;
-our $VERSION = '0.2.0';
+our $VERSION = '0.2.5';
 
 sub new
 {
@@ -19,14 +21,18 @@ sub new
     croak "Arguments not supplied as a hash reference.\n" unless 'HASH' eq ref $args;
 
     my $self = bless {
-        height => 10,
+        height => 12,
         width => 0,
         -nodecl => 0,
         -allns => 0,
+        pady => 1,
+        padx => 0,
         color => '#000',
         %{$args},
     }, $class;
 
+    $self->{xoff} = -$self->{padx};
+
     $self->_make( $type );
 
     return $self;
@@ -60,7 +66,7 @@ SVG::Sparkline - Create Sparklines in SVG
 
 =head1 VERSION
 
-This document describes SVG::Sparkline version 0.2.0
+This document describes SVG::Sparkline version 0.2.5
 
 =head1 SYNOPSIS
 
@@ -136,6 +142,17 @@ a color for the background of the sparkline. In general, this parameter should
 not be supplied or should be very subtle to avoid taking attention away from
 the actual data displayed.
 
+=item -padx
+
+The value of this parameter is the number of pixels of padding inside the
+sparkline, but to the left of the first data point and right of the last
+data point. 
+
+=item -pady
+
+The value of this parameter is the number of pixels of padding inside the
+sparkline, but above the highest data point and below the lowest data point.
+
 =back
 
 =head3 Attribute Parameters
@@ -168,6 +185,60 @@ This optional parameter specifies the color for the displayed data as an
 SVG supported color string. Each sparkline type uses this color slightly
 differently.
 
+=item mark
+
+There are times when certain points on the sparkline need to be highlighted
+in some way. For instance, you might want to highlight the lowest and highest
+value of a data set. The C<mark> attribute supports this functionality.
+
+The appearance of the mark is mostly determined by the sparkline type. However,
+you may select different colors for each mark.
+
+The value of the C<mark> attribute is a reference to an array of pairs, where
+each pair consists of an index and a color. The index is either an integer
+specifying which point in the C<values> is to be marked or a string that
+describes a particular point. The supported index strings are
+
+=over 4
+
+=item first
+
+This index string represents the first data point. It is synonymous with a
+numeric index of 0.
+
+=item last
+
+This index string represents the last data point. It is equal to one less than
+the number of C<values>.
+
+=item high
+
+This index string repesents the highest value in the data set. If there is more
+than one point with the highest value, the first index with this value is
+selected.
+
+=item low
+
+This index string repesents the lowest value in the data set. If there is more
+than one point with the lowest value, the first index with this value is
+selected.
+
+=back
+
+The following would be examples of marks:
+
+=over 4
+
+=item Single Indexed Mark
+
+   mark => [ 3 => 'blue' ]
+
+=item High and Low Marks
+
+  mark => [ low => 'red', high => 'green' ]
+
+=back
+
 =back
 
 The supported graph types are: B<Area>, B<Bar>, B<Line>, and B<Whisker>.
@@ -198,6 +269,11 @@ This optional parameter specifies the color of the filled area between the
 data line and the x-axis as a SVG supported color string. The default value
 for this parameter is I<#000> (black).
 
+=item mark
+
+The mark for an Area is a vertical line of the specified color. The line moves
+from a value of zero up to the value.
+
 =back
 
 =head3 Bar
@@ -232,6 +308,10 @@ This optional parameter specifies the color of the filled area between the
 data line and the x-axis as a SVG supported color string. The default value
 for this parameter is I<#000> (black).
 
+=item mark
+
+The mark for Bar replaces the bar in question with one of the specified color.
+
 =back
 
 =head3 Line
@@ -263,6 +343,12 @@ If not specified, the default value is 1 pixel.
 This optional parameter specifies the color of the data line as a SVG supported
 color string. The default value for this parameter is I<#000> (black).
 
+=item mark
+
+The mark for Line is a dot of the specified color at the chosen location. The
+radius of the dot is the same as the width of the line, specified by the
+C<thick> parameter.
+
 =back
 
 =head3 Whisker
@@ -316,11 +402,17 @@ This optional parameter specifies the color of the individual whiskers as a
 SVG supported color string. The default value for this parameter is I<#000>
 (black).
 
+=item mark
+
+The mark for Whisker replaces the whisker in question with one of the
+specified color.
+
 =back
 
 =head2 to_string
 
-Convert the L<SVG::Sparkline> object to an XML string.
+Convert the L<SVG::Sparkline> object to an XML string. This is the method that
+is used by the stringification overload.
 
 =head1 DIAGNOSTICS
 
@@ -347,10 +439,10 @@ Please report any bugs or feature requests to
 C<bug-svg-sparkline@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-=head1 FUTURE DIRECTIONS
+=head1 ACKNOWLEDGEMENTS
 
-I plan to support more optional features and more I<intelligence> so that
-the module can do a better job without you specifying everything.
+This module has been greatly improved by suggestions and corrections supplied
+but Robert Boone, Debbie Campbell, and Joshua Keroes.
 
 =head1 AUTHOR
 
